# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`zot`](#zot): Manage docker registry replacement (zot)

#### Private Classes

* `zot::config`: Manages configuration, merges Puppet hashes and serialized them into JSON config
* `zot::install`: Zot installation
* `zot::service`: Zot service

### Data types

* [`Zot::Arch`](#Zot--Arch): Supported build architecture
* [`Zot::Config`](#Zot--Config): Configuration passed to zot serve
* [`Zot::Os`](#Zot--Os): Supported operating system

## Classes

### <a name="zot"></a>`zot`

Manage docker registry replacement (zot)

* **See also**
  * https://zotregistry.io/

#### Examples

##### 

```puppet
include zot
```

##### 

```puppet
# using Puppet code
class { 'zot':
  config => {
     'http' => {
        'port' => 80,
     }
  }
}
```

#### Parameters

The following parameters are available in the `zot` class:

* [`version`](#-zot--version)
* [`binary`](#-zot--binary)
* [`bin_path`](#-zot--bin_path)
* [`config`](#-zot--config)
* [`defaults`](#-zot--defaults)
* [`user`](#-zot--user)
* [`group`](#-zot--group)
* [`config_dir`](#-zot--config_dir)
* [`log_dir`](#-zot--log_dir)
* [`data_dir`](#-zot--data_dir)
* [`manage_service`](#-zot--manage_service)
* [`manage_user`](#-zot--manage_user)
* [`user_ensure`](#-zot--user_ensure)
* [`manage_config`](#-zot--manage_config)
* [`manage_zli`](#-zot--manage_zli)
* [`manage_zb`](#-zot--manage_zb)
* [`service_name`](#-zot--service_name)
* [`service_ensure`](#-zot--service_ensure)
* [`service_enable`](#-zot--service_enable)
* [`download_mirror`](#-zot--download_mirror)
* [`arch`](#-zot--arch)
* [`os`](#-zot--os)
* [`uid`](#-zot--uid)
* [`gid`](#-zot--gid)
* [`limit_nofile`](#-zot--limit_nofile)
* [`memory_high`](#-zot--memory_high)
* [`memory_max`](#-zot--memory_max)

##### <a name="-zot--version"></a>`version`

Data type: `String`

Version to be fetched from github release page, without `v` prefix (see https://github.com/project-zot/zot/releases)

##### <a name="-zot--binary"></a>`binary`

Data type: `String`

Main executable name, default: `zot`

##### <a name="-zot--bin_path"></a>`bin_path`

Data type: `Stdlib::Unixpath`

Path for installing binaries, default: `/usr/bin`

##### <a name="-zot--config"></a>`config`

Data type: `Zot::Config`

Main zot configuration, as multi-level hash (see README for more examples)

##### <a name="-zot--defaults"></a>`defaults`

Data type: `Zot::Config`

Default values that would be overwritten by $config Hash

##### <a name="-zot--user"></a>`user`

Data type: `String`

Account running the service, default: `zot`

##### <a name="-zot--group"></a>`group`

Data type: `String`

Group owning service and config files, default: `zot`

##### <a name="-zot--config_dir"></a>`config_dir`

Data type: `Stdlib::Unixpath`

Directory storing zot service configuration, default: `/etc/zot`

##### <a name="-zot--log_dir"></a>`log_dir`

Data type: `Stdlib::Unixpath`

Directory used for storing log files

##### <a name="-zot--data_dir"></a>`data_dir`

Data type: `Stdlib::Unixpath`

Directory used for storing registry data

##### <a name="-zot--manage_service"></a>`manage_service`

Data type: `Boolean`

Whether service should be managed by Puppet, default: `true`

##### <a name="-zot--manage_user"></a>`manage_user`

Data type: `Boolean`

Whether user account should be managed by Puppet, default: `true`

##### <a name="-zot--user_ensure"></a>`user_ensure`

Data type: `String`

`present` or `absent`, default: `present`

##### <a name="-zot--manage_config"></a>`manage_config`

Data type: `Boolean`

Whether zot config should be managed by Puppet, default: `true`

##### <a name="-zot--manage_zli"></a>`manage_zli`

Data type: `Boolean`

Whether zli binary should be installed, default: `true`

##### <a name="-zot--manage_zb"></a>`manage_zb`

Data type: `Boolean`

Whether zb binary should be installed, default: `true`

##### <a name="-zot--service_name"></a>`service_name`

Data type: `String`



##### <a name="-zot--service_ensure"></a>`service_ensure`

Data type: `String`



##### <a name="-zot--service_enable"></a>`service_enable`

Data type: `Boolean`



##### <a name="-zot--download_mirror"></a>`download_mirror`

Data type: `Stdlib::HTTPUrl`

URI used for downloading zot binaries

##### <a name="-zot--arch"></a>`arch`

Data type: `Zot::Arch`

Release architecture, eiter `amd64` or `arm64`. Default: `amd64`

##### <a name="-zot--os"></a>`os`

Data type: `Zot::Os`

Used for downloading precompiled binary for given OS, default: `linux`

##### <a name="-zot--uid"></a>`uid`

Data type: `Optional[Integer]`

User account UID

Default value: `undef`

##### <a name="-zot--gid"></a>`gid`

Data type: `Optional[Integer]`

Group ID

Default value: `undef`

##### <a name="-zot--limit_nofile"></a>`limit_nofile`

Data type: `Integer`

Limit number of opened files for systemd service, default: `500000`

##### <a name="-zot--memory_high"></a>`memory_high`

Data type: `Optional[String]`

Systemd service throttling limit on memory usage

Default value: `undef`

##### <a name="-zot--memory_max"></a>`memory_max`

Data type: `Optional[String]`

Systemd service, the absolute limit on memory usage, see https://www.freedesktop.org/software/systemd/man/latest/systemd.resource-control.html

Default value: `undef`

## Data types

### <a name="Zot--Arch"></a>`Zot::Arch`

Supported build architecture

Alias of `Enum['amd64', 'arm64']`

### <a name="Zot--Config"></a>`Zot::Config`

Configuration passed to zot serve

Alias of

```puppet
Struct[{
  Optional[distSpecVersion] => String[1],
  Optional[storage]         => Hash,
  Optional[http]            => Hash,
  Optional[log]             => Hash,
  Optional[extensions]      => Hash,
  Optional[scheduler]       => Hash,
}]
```

### <a name="Zot--Os"></a>`Zot::Os`

Supported operating system

Alias of `Enum['linux', 'freebsd', 'darwin']`

